# mkdocs-ansible theme

This [mkdocs](https://www.mkdocs.org/) theme is based on [mkdocs-material](https://squidfunk.github.io/mkdocs-material/) and aims to provide a consistent
look and feel for any project related to [Ansible](https://docs.ansible.com/) ecosystem.

Some of the projects that use this theme are:

- [ansible-compat](https://ansible.readthedocs.io/projects/compat/)
- [ansible-dev-tools](https://ansible.readthedocs.io/projects/dev-tools/)
- [ansible-language-server](https://ansible.readthedocs.io/projects/language-server/)
- [ansible-lint](https://ansible.readthedocs.io/projects/lint/)
- [ansible-navigator](https://ansible.readthedocs.io/projects/navigator/)
- [molecule](https://ansible.readthedocs.io/projects/molecule/)
